*************************************************************
*                   1991 and 2000 Censuses                  *
*Fixed date residence - numerator and denominator by regions*
*************************************************************;
libname use 'E:\demo\paper\data\2000';
libname sta 'E:\demo\paper\data\regfix\2000';
options obs=max;

/*numerator*/
proc freq data = use.br noprint;
  tables region*regfix*sex*age / nocol norow nopercent out = sta.migfix;
  weight original;
run;

/*denominator - total population at the beginning of the period*/
proc freq data = use.br noprint;
  tables regfix*sex*age / nocol norow nopercent out = sta.popfix1;
  weight original;
run;

/*denominator 2 - total population at the end of the period*/
proc freq data = use.br noprint;
  tables region*sex*age / nocol norow nopercent out = sta.popfix2;
  weight original;
run;

/*beginning of the period - rename variables*/ 
data sta.den1;
  set sta.popfix1;
weight1=count;
run;

/*beginning of the period - keeping some variables*/
data sta.den1;
  set sta.den1;
  keep regfix sex age weight1;
run;

/*beginning of the period - proc sort*/
proc sort data = sta.den1;
  by regfix sex age weight1;
run;

/*end of the period - rename variables*/ 
data sta.den2;
  set sta.popfix2;
regfix=region;
weight2=count;
run;

/*end of the period - keeping some variables*/
data sta.den2;
  set sta.den2;
  keep regfix sex age weight2;
run;

/*end of the period - proc sort*/
proc sort data = sta.den2;
  by regfix sex age weight2;
run;

/*merge of beginning and end of the period to create denominator of formula*/
data sta.den;
  merge sta.den1 sta.den2;
  by regfix sex age;
den = 5 * ((weight1 + weight2)/2);
run;

/*numerator - rename variables*/ 
data sta.num;
  set sta.migfix;
migfix=count;
run;

/*numerator - keeping some variables*/
data sta.num;
  set sta.num;
  keep regfix region sex age migfix;
run;

/*numerator - proc sort*/
proc sort data = sta.num;
  by regfix sex age;
run;

/*denominator - proc sort*/
proc sort data = sta.den;
  by regfix sex age;
run;

/*2000: merge of numerator and denominator to create rate variable*/
data sta.merge;
  merge sta.num sta.den;
  by regfix sex age;
rate00 = migfix / den * 10000;
run;

proc sort data=sta.merge;
  by regfix region sex age;
run;

/*final database with rates, without migrant and person-years variables*/
data sta.final;
  set sta.merge;
  by regfix region sex age;
  keep regfix region sex age rate00;
  if rate00^=. and regfix^=region;
  label regfix='Region at a fixed prior date' region='Region of residence'
        sex='Sex' rate00='1995-1999';
run;

/*final database to construct tables*/
data sta.table;
  set sta.final;
aser00 = rate00 / 10000;
drop rate00;
label aser00='1995-1999';
run;
